@@ -1,12 +1,14 @@
 package Acme::CPANModules::COLOR;
 
+use strict;
+
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-05-10'; # DATE
+our $DATE = '2023-08-06'; # DATE
 our $DIST = 'Acme-CPANModules-COLOR'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 our $LIST = {
-    summary => "Modules that follow the COLOR & NO_COLOR convention",
+    summary => "List of modules that follow the COLOR & NO_COLOR convention",
     description => <<'_',
 
 The NO_COLOR convention (see https://no-color.org) lets user disable color
@@ -60,7 +62,7 @@ _
 };
 
 1;
-# ABSTRACT: Modules that follow the COLOR & NO_COLOR convention
+# ABSTRACT: List of modules that follow the COLOR & NO_COLOR convention
 
 __END__
 
@@ -70,11 +72,11 @@ __END__
 
 =head1 NAME
 
-Acme::CPANModules::COLOR - Modules that follow the COLOR & NO_COLOR convention
+Acme::CPANModules::COLOR - List of modules that follow the COLOR & NO_COLOR convention
 
 =head1 VERSION
 
-This document describes version 0.004 of Acme::CPANModules::COLOR (from Perl distribution Acme-CPANModules-COLOR), released on 2021-05-10.
+This document describes version 0.005 of Acme::CPANModules::COLOR (from Perl distribution Acme-CPANModules-COLOR), released on 2023-08-06.
 
 =head1 DESCRIPTION
 
@@ -97,57 +99,109 @@ If you know of other modules that should be listed here, please contact me.
 
 =over
 
-=item * L<AppBase::Grep>
+=item L<AppBase::Grep>
 
-=item * L<App::abgrep>
+Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
 
-=item * L<App::diffdb>
+=item L<App::abgrep>
 
-=item * L<App::DiffTarballs>
+Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
 
-=item * L<App::diffwc>
+Script: L<abgrep>
 
-=item * L<App::hr>
+=item L<App::diffdb>
 
-=item * L<App::riap>
+Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
 
-=item * L<App::wordlist>
+=item L<App::DiffTarballs>
 
-=item * L<Color::ANSI::Util>
+Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
 
-=item * L<Data::Dump::Color>
+=item L<App::diffwc>
 
-=item * L<Data::Format::Pretty::JSON>
+Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
 
-=item * L<Data::Format::Pretty::Perl>
+=item L<App::hr>
 
-=item * L<Data::Format::Pretty::YAML>
+Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
 
-=item * L<Debug::Print>
+=item L<App::riap>
 
-=item * L<Log::Any::Adapter::Screen>
+Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
 
-=item * L<Log::ger::Output::Screen>
+=item L<App::wordlist>
 
-=item * L<Perinci::CmdLine::Classic>
+Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
 
-=item * L<Perinci::CmdLine::Lite>
+=item L<Color::ANSI::Util>
 
-=item * L<Perinci::Result::Format>
+Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
 
-=item * L<Perinci::Result::Format::Lite>
+=item L<Data::Dump::Color>
 
-=item * L<Progress::Any::Output::TermProgressBar>
+Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
 
-=item * L<Term::ANSIColor::Conditional>
+=item L<Data::Format::Pretty::JSON>
 
-=item * L<Term::ANSIColor::Patch::Conditional>
+Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
 
-=item * L<Term::App::Roles>
+=item L<Data::Format::Pretty::Perl>
 
-=item * L<Text::ANSITable>
+Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
 
-=item * L<Text::DiffU>
+=item L<Data::Format::Pretty::YAML>
+
+Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
+
+=item L<Debug::Print>
+
+Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
+
+=item L<Log::Any::Adapter::Screen>
+
+Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
+
+=item L<Log::ger::Output::Screen>
+
+Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
+
+=item L<Perinci::CmdLine::Classic>
+
+Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
+
+=item L<Perinci::CmdLine::Lite>
+
+Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
+
+=item L<Perinci::Result::Format>
+
+Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
+
+=item L<Perinci::Result::Format::Lite>
+
+Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
+
+=item L<Progress::Any::Output::TermProgressBar>
+
+=item L<Term::ANSIColor::Conditional>
+
+Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
+
+=item L<Term::ANSIColor::Patch::Conditional>
+
+Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
+
+=item L<Term::App::Roles>
+
+Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
+
+=item L<Text::ANSITable>
+
+Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
+
+=item L<Text::DiffU>
+
+Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
 
 =back
 
@@ -162,8 +216,13 @@ document CPAN. See L<Acme::CPANModules> for more details.
 =head2 What are ways to use this Acme::CPANModules module?
 
 Aside from reading this Acme::CPANModules module's POD documentation, you can
-install all the listed modules (entries) using L<cpanmodules> CLI (from
-L<App::cpanmodules> distribution):
+install all the listed modules (entries) using L<cpanm-cpanmodules> script (from
+L<App::cpanm::cpanmodules> distribution):
+
+ % cpanm-cpanmodules -n COLOR
+
+Alternatively you can use the L<cpanmodules> CLI (from L<App::cpanmodules>
+distribution):
 
     % cpanmodules ls-entries COLOR | cpanm -n
 
@@ -178,6 +237,8 @@ or directly:
 This Acme::CPANModules module also helps L<lcpan> produce a more meaningful
 result for C<lcpan related-mods> command when it comes to finding related
 modules for the modules listed in this Acme::CPANModules module.
+See L<App::lcpan::Cmd::related_mods> for more details on how "related modules"
+are found.
 
 =head1 HOMEPAGE
 
@@ -187,14 +248,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Acme-CPANM
 
 Source repository is at L<https://github.com/perlancar/perl-Acme-CPANModules-COLOR>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-CPANModules-COLOR>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<Acme::CPANModules> - about the Acme::CPANModules namespace
@@ -205,11 +258,37 @@ L<cpanmodules> - CLI tool to let you browse/view the lists
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020, 2018 by perlancar@cpan.org.
+This software is copyright (c) 2023, 2021, 2020, 2018 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-CPANModules-COLOR>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
